from tracardi_plugin_sdk.domain.register import Plugin, Spec, MetaData
from tracardi_plugin_sdk.action_runner import ActionRunner
from tracardi_plugin_sdk.domain.result import Result
from tracardi_string_splitter.model.model import Splitter


class SplitterAction(ActionRunner):

    def __init__(self, **kwargs):
        self.splitter = Splitter(**kwargs)

    async def run(self, payload):
        result = self.splitter.string.split(self.splitter.delimiter)
        return Result(port="payload", value={
                "result": result
            })


def register() -> Plugin:
    return Plugin(
        start=False,
        spec=Spec(
            module='tracardi_string_splitter.plugin',
            className='SplitterAction',
            inputs=["payload"],
            outputs=['payload'],
            version='0.1.1',
            license="MIT",
            author="Bartosz Dobrosielski",
            init={
                "string": None,
                "delimiter": '.',
            }

        ),
        metadata=MetaData(
            name='Splitter',
            desc='String splitter',
            type='flowNode',
            width=200,
            height=100,
            icon='splitter',
            group=["Traits"]
        )
    )



from pydantic import validator
from pydantic.main import BaseModel


class Splitter(BaseModel):
    string: str
    delimiter: str

    @validator('string')
    def myst_have_2_letter(cls, v):
        if len(v) < 2:
            raise ValueError('String is too short. String must be at least two letters long.')
        return v




from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='tracardi-string-splitter',
    version='0.1.1',
    description='The purpose of this plugin is split any string',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Bartosz Dobrosielski`',
    author_email='bdobrosielski@edu.cdv.pl',
    packages=['tracardi_string_splitter'],
    install_requires=[
        'tracardi-plugin-sdk'
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    keywords=['tracardi', 'plugin'],
    python_requires=">=3.8",
    include_package_data=True
)